@@ -36,6 +36,10 @@ class Paths:
     def scanned_fields_dir() -> Path:
         return Paths.fields_dir(Paths.scanned_dir())
 
+    @staticmethod
+    def company_fields_dir() -> Path:
+        return Path.cwd() / SystemDirectory.FIELDS.value
+
     @staticmethod
     def fields_dir(package: Path) -> Path:
         return package / SystemDirectory.FIELDS.value
